]> diplodocus.org Git - nmh/blobdiff - uip/new.c
Remove unused NCWD and NPWD #defines.
[nmh] / uip / new.c
index 2bb8c17a2ae954065b1d71a0dbe2a851a9687325..ff9c398bb7a0646cf805ba969ae11e88bda7c86e 100644 (file)
--- a/uip/new.c
+++ b/uip/new.c
@@ -31,7 +31,13 @@ DEFINE_SWITCH_ENUM(NEW);
 DEFINE_SWITCH_ARRAY(NEW, switches);
 #undef X
 
-static enum { NEW, FNEXT, FPREV, UNSEEN } run_mode = NEW;
+/* What to do, based on argv[0]. */
+static enum {
+    RM_NEW,
+    RM_FNEXT,
+    RM_FPREV,
+    RM_UNSEEN
+} run_mode = RM_NEW;
 
 /* check_folders uses this to maintain state with both .folders list of
  * folders and with crawl_folders. */
@@ -201,9 +207,10 @@ check_folder(char *folder, size_t len, struct list_state *b)
 
     if (is_cur || msgnums != NULL) {
        if (*b->first == NULL) {
-           *b->first = b->node = mh_xmalloc(sizeof(*b->node));
+           NEW(b->node);
+           *b->first = b->node;
        } else {
-           b->node->n_next = mh_xmalloc(sizeof(*b->node));
+           NEW(b->node->n_next);
            b->node = b->node->n_next;
        }
        b->node->n_name = folder;
@@ -273,7 +280,7 @@ check_folders(struct node **first, struct node **last,
        while (vfgets(fp, &line) == OK) {
            len = strlen(line) - 1;
            line[len] = '\0';
-           check_folder(getcpy(line), len, &b);
+           check_folder(mh_xstrdup(line), len, &b);
        }
        fclose(fp);
     }
@@ -309,8 +316,8 @@ join_sequences(char *sequences[])
 }
 
 /* Return a struct node for the folder to change to.  This is the next
* (previous, if FPREV mode) folder with desired messages, or the current
* folder if no folders have desired.  If NEW or UNSEEN mode, print the
  * output but don't change folders.
  *
  * n_name is the folder to change to, and n_field is the string list of
@@ -331,35 +338,36 @@ doit(char *cur, char *folders, char *sequences[])
     check_folders(&first, &last, &cur_node, &folder_len, cur,
                  folders, sequences);
 
-    if (run_mode == FNEXT || run_mode == FPREV) {
+    if (run_mode == RM_FNEXT || run_mode == RM_FPREV) {
        if (first == NULL) {
            /* No folders at all... */
            return NULL;
-       } else if (first->n_next == NULL) {
+       }
+        if (first->n_next == NULL) {
            /* We have only one node; any desired messages in it? */
            if (first->n_field == NULL) {
                return NULL;
-           } else {
-               return first;
            }
-       } else if (cur_node == NULL) {
+            return first;
+       }
+        if (cur_node == NULL) {
            /* Current folder is not listed in .folders, return first. */
            return first;
        }
-    } else if (run_mode == UNSEEN) {
+    } else if (run_mode == RM_UNSEEN) {
        sequences_s = join_sequences(sequences);
     }
 
     for (node = first, prev = NULL;
         node != NULL;
         prev = node, node = node->n_next) {
-        if (run_mode == FNEXT) {
+        if (run_mode == RM_FNEXT) {
             /* If we have a previous node and it is the current
              * folder, return this node. */
             if (prev != NULL && strcmp(prev->n_name, cur) == 0) {
                 return node;
             }
-        } else if (run_mode == FPREV) {
+        } else if (run_mode == RM_FPREV) {
             if (strcmp(node->n_name, cur) == 0) {
                 /* Found current folder in fprev mode; if we have a
                  * previous node in the list, return it; else return
@@ -369,7 +377,9 @@ doit(char *cur, char *folders, char *sequences[])
                 }
                 return prev;
             }
-        } else if (run_mode == UNSEEN) {
+        } else if (run_mode == RM_UNSEEN) {
+            int status;
+
             if (node->n_field == NULL) {
                 continue;
             }
@@ -388,7 +398,8 @@ doit(char *cur, char *folders, char *sequences[])
            /* TODO: Split enough of scan.c out so that we can call it here. */
            command = concat("scan +", node->n_name, " ", sequences_s,
                             (void *)NULL);
-           if (system(command) == NOTOK) {
+           status = system(command);
+           if (! WIFEXITED (status)) {
                adios (command, "system");
            }
            free(command);
@@ -410,14 +421,14 @@ doit(char *cur, char *folders, char *sequences[])
 
     /* If we're fnext, we haven't checked the last node yet.  If it's the
      * current folder, return the first node. */
-    if (run_mode == FNEXT) {
+    if (run_mode == RM_FNEXT) {
        assert(last != NULL);
        if (strcmp(last->n_name, cur) == 0) {
             return first;
        }
     }
 
-    if (run_mode == NEW) {
+    if (run_mode == RM_NEW) {
         printf("%-*s %6d.\n", (int) folder_len, " total", total);
     }
 
@@ -480,11 +491,11 @@ main(int argc, char **argv)
     }
 
     if (strcmp(invo_name, "fnext") == 0) {
-        run_mode = FNEXT;
+        run_mode = RM_FNEXT;
     } else if (strcmp(invo_name, "fprev") == 0) {
-        run_mode = FPREV;
+        run_mode = RM_FPREV;
     } else if (strcmp(invo_name, "unseen") == 0) {
-        run_mode = UNSEEN;
+        run_mode = RM_UNSEEN;
     }
 
     if (folders == NULL) {
@@ -513,7 +524,7 @@ main(int argc, char **argv)
         return 1;
     }
 
-    if (run_mode == UNSEEN) {
+    if (run_mode == RM_UNSEEN) {
         /* All the scan(1)s it runs change the current folder, so we
          * need to put it back.  Unfortunately, context_replace lamely
          * ignores the new value you give it if it is the same one it
@@ -525,7 +536,7 @@ main(int argc, char **argv)
     /* update current folder */
     context_replace(pfolder, folder->n_name);
 
-    if (run_mode == FNEXT || run_mode == FPREV) {
+    if (run_mode == RM_FNEXT || run_mode == RM_FPREV) {
         printf("%s  %s\n", folder->n_name, folder->n_field);
     }
@@ -309,8 +316,8 @@ join_sequences(char *sequences[])
 
 /* Return a struct node for the folder to change to.  This is the next
- * (previous, if FPREV mode) folder with desired messages, or the current
- * folder if no folders have desired.  If NEW or UNSEEN mode, print the
+ * (previous, if RM_FPREV mode) folder with desired messages, or the current
+ * folder if no folders have desired.  If RM_NEW or RM_UNSEEN mode, print the
  * output but don't change folders.
  *